@@ -131,6 +131,8 @@ class DagArgsSchema(StrictSchema):
     user_defined_filters = fields.Dict()
     doc_md = fields.String()
     access_control = fields.Dict()
+    # tags requires at least version 1.10.8
+    tags = fields.List(fields.String())
 
     @validates_schema
     def validate_callbacks(self, data):
